@@ -6,10 +6,7 @@ from sphinx.environment.collectors import EnvironmentCollector
 from sphinx import addnodes
 from sphinx.util.osutil import relative_uri
 
-__version__ = (1, 1, 2)
-
-
-sys.setrecursionlimit(15000)
+__version__ = (2, 0, 0)
 
 
 class SimpleTocTreeCollector(EnvironmentCollector):
@@ -159,15 +156,10 @@ def add_toctree_data(app, pagename, templatename, context, doctree):
 def on_config_inited(app, conf):
     exclude_files = list(app.config.get('epub_exclude_files', []))
     exclude_files.append('_static/sphinx_nervproject_theme.js')
-    exclude_files.append('_static/sphinx_nervproject_simple.css')
     exclude_files.append('_static/sphinx_nervproject_theme.css')
     exclude_files.append('_static/basic.css')
     app.config.exclude_files = exclude_files
 
-    app.config.weasyprint_footer_selector = 'footer.footer'
-    app.config.weasyprint_header_selector = 'header.navbar'
-
-
 def setup(app):
     app.add_env_collector(SimpleTocTreeCollector)
     app.connect('html-page-context', add_toctree_data)
